Dependents

Struct Dependents 

pub struct Dependents<J>(/* private fields */);
A reference to the jobs dependent on a queued job.

Implementations

Source

impl<J> Dependents<J>

pub fn new(dependents: Vec<Edge<J>>) -> Arc<Self>

Construct a new dependent list from its inner vector

pub fn push<H: SchedulerCore<J>>(&self, handle: &H, dependent: Edge<J>)

Push a new dependent job into this dependents list.

If the job associated with this list has already run, the job will be enqueued immediately.