pub struct Dependents<J>(/* private fields */);Expand description
A reference to the jobs dependent on a queued job.
Implementations
Sourceimpl<J> Dependents<J>
impl<J> Dependents<J>
Sourcepub fn new(dependents: Vec<Edge<J>>) -> Arc<Self>
pub fn new(dependents: Vec<Edge<J>>) -> Arc<Self>
Construct a new dependent list from its inner vector
Sourcepub fn push<H: SchedulerCore<J>>(&self, handle: &H, dependent: Edge<J>)
pub fn push<H: SchedulerCore<J>>(&self, handle: &H, dependent: Edge<J>)
Push a new dependent job into this dependents list.
If the job associated with this list has already run, the job will be enqueued immediately.