pub struct NodeBuilder<J> { /* private fields */ }Expand description
Helper struct for parceling out node dependencies
Panics
This struct panics on drop if not all dependencies are used, as this results in a node that cannot run.
Implementations
Sourceimpl<J> NodeBuilder<J>
impl<J> NodeBuilder<J>
Sourcepub fn get_in_edge(&mut self) -> Edge<J>
pub fn get_in_edge(&mut self) -> Edge<J>
Request a single inbound edge (dependency).
Panics
This method panics if no more dependency handles are available.
Sourcepub fn try_get_in_edge(&mut self) -> Option<Edge<J>>
pub fn try_get_in_edge(&mut self) -> Option<Edge<J>>
Request a single inbound edge (dependency), returning None if no more
are available.
Sourcepub fn set_dependents(
&mut self,
dependents: Arc<Dependents<J>>,
) -> Result<(), Arc<Dependents<J>>>
pub fn set_dependents( &mut self, dependents: Arc<Dependents<J>>, ) -> Result<(), Arc<Dependents<J>>>
Add a list of dependents to this node.
Errors
This function returns the input dependent list as an error if the node is no longer available to be accessed safely or if a dependent list has already been assigned to the node.